%function runBatchJob()
% Purpose: wrapper that calls user's program
% Motivation: When a user runs many parallel jobs via batch, lots of
% MATLAB internal files are generated. These batch-related I/O are
% inefficient between the runtime assigned compute node and the user's
% home sub-dir (~/.matlab). This m-file will re-direct these to the
% compute node's temporary TMPDIR foder. 

[nslots, task] = getbev;    % get batch-generated env vars

% myApp computes Arithmetic Sequence Sum. Input: n, nslots
% s = 1 + 2 + 3 + . . . + n
n = 1000;
if task ~= 'undefined'
  n = task * 1000;  % for Array Jobs,each job has its only n
end

myCluster = parcluster('local')   % job on a compute node is "local"
if isBatch
  myCluster.JobStorageLocation = getenv('TMPDIR');  % for batch job
end

% Example 1: for function m-file myApp.m
% It computes Arithmetic Sequency sum s = 1+2+3+ . . . + n
job1 = batch(myCluster, 'myApp', 3, {n, nslots}, 'Pool', nslots);
wait(job1);   % wait for job to finish
% A function needs fetchOutputs to recover output (cell array)
data=fetchOutputs(job1)  % recover output for function m-file
data{1}  % prints output txt of myApp
data{2}  % prints output s   of myApp
data{3}  % spmd output x 

% Example 2: for script m-file myWave.m
% Computes transcendantal function A(1:n) = sin(...)
job2 = batch(myCluster, 'myWave', 'Pool', nslots)  % submit batch
wait(job2)        % wait for job to finish
load(job2, 'A')   % to recover batch output for script m-file
A(1:6)            % print output array A (double)

%end
